@@ -17,25 +17,43 @@ class Pi(WBits):
         self._set_command(command)
 
     
-    def print(self, row, column, text):
+    def print(self, row, column, *text):
         """
         在某个位置显示内容，位置坐标以像素点为单位
 
         :param row: 显示行数：1~64
         :param column: 显示列数：1~128
-        :param text: 显示内容，可以是字符串，整数，小数
+        :param *text: 显示内容，可以是字符串，整数，小数
         """
 
-        text = _format_str_type(text)
         
         args = []
         args.append(str(row))
         args.append(str(column))
-        args.append(str(text))
+        for _text in text:
+            _text = _format_str_type(_text)
+            args.append(str(_text))
         command = 'Pi{}.print({})'.format(self.index, ",".join(args))
         self._set_command(command)
 
     
+    def draw_chart(self, x, y = None):
+        """
+        传入(x,y)坐标以上次传入的坐标为起点，本次坐标为终点画线段。如果是首次使用，则只画单个点传入列表则以列表中的值为纵坐标，自动计算横坐标将折线图展示在屏幕上
+
+        :param x: X轴坐标：1~128
+        :param y: Y轴坐标：1~64
+        """
+
+        
+        args = []
+        args.append(str(x))
+        if y != None:
+            args.append(str(y))
+        command = 'Pi{}.draw_chart({})'.format(self.index, ",".join(args))
+        self._set_command(command)
+
+    
     def draw_dot(self, x, y):
         """
         
@@ -143,7 +161,7 @@ class Pi(WBits):
 
         command = 'Pi{}.is_a_pressed()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
     def is_b_pressed(self):
         """
@@ -153,21 +171,22 @@ class Pi(WBits):
 
         command = 'Pi{}.is_b_pressed()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
-    def is_touched(self, pad):
+    def is_touched(self, pad = None):
         """
-        获取某通道是否被触摸
+        获取某通道是否被触摸不填写通道参数可以支持检测多个通道，无通道被触摸返回False，有通道被触摸返回以该通道字母组成的字符串
         :rtype: bool
         """
 
         pad = _format_str_type(pad)
         
         args = []
-        args.append(str(pad))
+        if pad != None:
+            args.append(str(pad))
         command = 'Pi{}.is_touched({})'.format(self.index, ",".join(args))
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
     def get_volume(self):
         """
@@ -177,9 +196,9 @@ class Pi(WBits):
 
         command = 'Pi{}.get_volume()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
-    def get_light(self, index):
+    def get_light(self, index = None):
         """
         亮度值代表相对强度，值越大代表亮度越强
         :rtype: int
@@ -188,10 +207,11 @@ class Pi(WBits):
         index = _format_str_type(index)
         
         args = []
-        args.append(str(index))
+        if index != None:
+            args.append(str(index))
         command = 'Pi{}.get_light({})'.format(self.index, ",".join(args))
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
     def get_temperature(self):
         """
@@ -201,7 +221,7 @@ class Pi(WBits):
 
         command = 'Pi{}.get_temperature()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
     def get_humidity(self):
         """
@@ -211,7 +231,7 @@ class Pi(WBits):
 
         command = 'Pi{}.get_humidity()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
     def get_air_pressure(self):
         """
@@ -221,9 +241,9 @@ class Pi(WBits):
 
         command = 'Pi{}.get_air_pressure()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
-    def get_angle(self, axis):
+    def get_angle(self, axis = None):
         """
         获取某轴倾斜角，单位°
         :rtype: float
@@ -232,10 +252,11 @@ class Pi(WBits):
         axis = _format_str_type(axis)
         
         args = []
-        args.append(str(axis))
+        if axis != None:
+            args.append(str(axis))
         command = 'Pi{}.get_angle({})'.format(self.index, ",".join(args))
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
     def get_acceleration(self, axis = None):
         """
@@ -250,8 +271,68 @@ class Pi(WBits):
             args.append(str(axis))
         command = 'Pi{}.get_acceleration({})'.format(self.index, ",".join(args))
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
+    def reset(self):
+        """
+        
+
+        """
+
+        command = 'Pi{}.reset()'.format(self.index)
+        self._set_command(command)
+
+    
+    def radio_on(self, channel = None):
+        """
+        可填写参数设置通信信道，默认为1
+
+        :param channel: 信道参数: 1~13，默认为1
+        """
+
+        
+        args = []
+        if channel != None:
+            args.append(str(channel))
+        command = 'Pi{}.radio_on({})'.format(self.index, ",".join(args))
+        self._set_command(command)
+
+    
+    def radio_send(self, s):
+        """
+        设置为相同信道的豌豆派会接收到字符串
+
+        :param s: 需要发送的字符串
+        """
+
+        s = _format_str_type(s)
+        
+        args = []
+        args.append(str(s))
+        command = 'Pi{}.radio_send({})'.format(self.index, ",".join(args))
+        self._set_command(command)
+
+    
+    def radio_receive(self):
+        """
+        接收设置为相同信道的豌豆派发送的字符串若是没有收到新的字符串则会返回空字符串
+        :rtype: str
+        """
+
+        command = 'Pi{}.radio_receive()'.format(self.index)
+        value = self._get_command(command)
+        return value
+        
+    def radio_off(self):
+        """
+        
+
+        """
+
+        command = 'Pi{}.radio_off()'.format(self.index)
+        self._set_command(command)
+
+    
 
     
 
