@@ -25,7 +25,7 @@ class Slider(WBits):
 
         command = 'slider{}.get_position()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
 
     
